@@ -143,6 +143,21 @@ class GitReviewTestCase(tests.BaseGitReviewTestCase):
             'refs/remotes/%s/master' % self._remote,
             self._run_git("for-each-ref", "--format='%(upstream)'", head))
 
+        # add some more changes & upload
+        self._simple_amend('test 2nd rev',
+                           self._dir('test', '2nd_rev_file.txt'))
+        self._run_git_review('-v')
+        self._simple_amend('test 3rd rev',
+                           self._dir('test', '3rd_rev_file.txt'))
+        self._run_git_review('-v')
+
+        # get rev 2; assert rev2 file is there, but not rev3
+        self._run_git_review('-d', '%s,%s' % (change_id, 2))
+        self.assertIn('2nd_rev_file.txt',
+                      self._run_git('show', 'HEAD'))
+        self.assertNotIn('3rd_rev_file.txt',
+                         self._run_git('show', 'HEAD'))
+
     def test_multiple_changes(self):
         """Test git-review asks about multiple changes.
 
@@ -371,12 +386,13 @@ class GitReviewTestCase(tests.BaseGitReviewTestCase):
     def test_git_review_t(self):
         self._run_git_review('-s')
         self._simple_change('test file modified', 'commit message for bug 654')
-        self._assert_branch_would_be('master/zat', extra_args=['-t', 'zat'])
+        self._assert_branch_would_be('master%topic=zat',
+                                     extra_args=['-t', 'zat'])
 
     def test_bug_topic(self):
         self._run_git_review('-s')
         self._simple_change('a change', 'new change for bug 123')
-        self._assert_branch_would_be('master/bug/123')
+        self._assert_branch_would_be('master%topic=bug/123')
 
     def test_bug_topic_newline(self):
         self._run_git_review('-s')
@@ -386,7 +402,7 @@ class GitReviewTestCase(tests.BaseGitReviewTestCase):
     def test_bp_topic(self):
         self._run_git_review('-s')
         self._simple_change('a change', 'new change for blueprint asdf')
-        self._assert_branch_would_be('master/bp/asdf')
+        self._assert_branch_would_be('master%topic=bp/asdf')
 
     def test_bp_topic_newline(self):
         self._run_git_review('-s')
@@ -460,7 +476,7 @@ class GitReviewTestCase(tests.BaseGitReviewTestCase):
     def test_git_review_T(self):
         self._run_git_review('-s')
         self._simple_change('test file modified', 'commit message for bug 456')
-        self._assert_branch_would_be('master/bug/456')
+        self._assert_branch_would_be('master%topic=bug/456')
         self._assert_branch_would_be('master', extra_args=['-T'])
 
     def test_git_review_T_t(self):
